@@ -14,19 +14,42 @@ hllm <- function(formula = ~.^1,  gmData, marginal){
   return(value)
 }
 
+## .fit.hllm <- function(m,engine="loglm",...){
+
+##   rawdata <- observations(m$gmData)
+##   if (is.data.frame(rawdata)){
+##     rawdata <- xtabs(~., rawdata)
+##   }
+##   value <- m
+##   mimform <- processFormula(formula(m),gmData(m),type="Discrete")
+##   switch(engine,
+##          "loglm"={
+##            mimformula <- mimform$mimformula
+##            loglm.formula <- formula(paste("~",mimformula))
+##            ##val <- loglm(loglm.formula, rawdata)
+##            val <- loglm(loglm.formula, data=rawdata)
+##            val$call$data <- rawdata
+##            class(value) <- c("gRfit","loglm", class(m))
+##          },
+##          {stop("Only engine 'loglm' currently implemented...")
+##         })
+##   value$fit <- val  
+##   return(value)
+## }
+
+
 fit.hllm <- function(m,engine="loglm",...){
+
   rawdata <- observations(m$gmData)
   if (is.data.frame(rawdata)){
     rawdata <- xtabs(~., rawdata)
   }
   value <- m
   mimform <- processFormula(formula(m),gmData(m),type="Discrete")
-  
+                                        #cat("processFormula done...\n")
   switch(engine,
          "loglm"={
-           mimformula <- mimform$mimformula
-           loglm.formula <- formula(paste("~",mimformula))
-           ##val <- loglm(loglm.formula, rawdata)
+           loglm.formula <- mimform$formula
            val <- loglm(loglm.formula, data=rawdata)
            val$call$data <- rawdata
            class(value) <- c("gRfit","loglm", class(m))
@@ -40,6 +63,9 @@ fit.hllm <- function(m,engine="loglm",...){
 
 
 
+
+
+
 stepwise.hllm <-    function (object, ...)
   {
 
